@@ -56,7 +56,7 @@ export const SKIP_CERT_MANAGER = boolean({
 export const SKIP_DEV_WORKSPACE_FLAG = 'skip-devworkspace-operator'
 export const SKIP_DEV_WORKSPACE = boolean({
   default: false,
-  description: 'Skip installing Dev Workspace Operator (Kubernetes cluster only).',
+  description: 'Skip installing Dev Workspace Operator.',
 })
 
 export const CHE_OPERATOR_CR_PATCH_YAML_FLAG = 'che-operator-cr-patch-yaml'
@@ -94,6 +94,7 @@ export const K8S_POD_DOWNLOAD_IMAGE_TIMEOUT = string({
   default: DEFAULT_K8S_POD_DOWNLOAD_IMAGE_TIMEOUT,
 })
 
+export const DEFAULT_K8S_POD_READY_TIMEOUT_EMBEDDED_PLUGIN_REGISTRY = '600000'
 export const DEFAULT_K8S_POD_READY_TIMEOUT = '60000'
 export const K8S_POD_READY_TIMEOUT_FLAG = 'k8spodreadytimeout'
 export const K8S_POD_READY_TIMEOUT = string({
@@ -173,12 +174,6 @@ export const WORKSPACE_PVS_STORAGE_CLASS_NAME = string({
   default: '',
 })
 
-export const POSTGRES_PVS_STORAGE_CLASS_NAME_FLAG = 'postgres-pvc-storage-class-name'
-export const POSTGRES_PVS_STORAGE_CLASS_NAME = string({
-  description: `persistent volume storage class name to use to store ${EclipseChe.PRODUCT_NAME} postgres database`,
-  default: '',
-})
-
 export const DEVFILE_REGISTRY_URL_FLAG = 'devfile-registry-url'
 export const DEVFILE_REGISTRY_URL = string({
   description: 'The URL of the external Devfile registry.',
