@@ -25,6 +25,7 @@ export namespace EclipseChe {
   export const VALIDATING_WEBHOOK = 'org.eclipse.che'
   export const MUTATING_WEBHOOK = 'org.eclipse.che'
   export const CONFIG_MAP = 'che'
+  export const PLUGIN_REGISTRY_CONFIG_MAP = 'plugin-registry'
   export const CONSOLE_LINK = 'che'
   export const PROMETHEUS = 'prometheus-k8s'
   export const IMAGE_CONTENT_SOURCE_POLICY = 'quay.io'
@@ -58,15 +59,14 @@ export namespace EclipseChe {
   export const OPERATOR_IMAGE_NEXT_TAG = 'next'
 
   // Doc links
-  export const DOC_LINK = 'https://access.redhat.com/documentation/en-us/red_hat_openshift_dev_spaces/3.5/'
-  export const DOC_LINK_RELEASE_NOTES = 'https://access.redhat.com/documentation/en-us/red_hat_openshift_dev_spaces/3.5/html/release_notes_and_known_issues/index'
+  export const DOC_LINK = 'https://access.redhat.com/documentation/en-us/red_hat_openshift_dev_spaces/3.6/'
+  export const DOC_LINK_RELEASE_NOTES = 'https://access.redhat.com/documentation/en-us/red_hat_openshift_dev_spaces/3.6/html/release_notes_and_known_issues/index'
   export const DOC_LINK_CONFIGURE_API_SERVER = 'https://kubernetes.io/docs/reference/access-authn-authz/authentication/#configuring-the-api-server'
 
   // Components
   export const CHE_SERVER = `${PRODUCT_NAME} Server`
   export const DASHBOARD = 'Dashboard'
   export const GATEWAY = 'Gateway'
-  export const POSTGRES = 'Postgres'
   export const DEVFILE_REGISTRY = 'Devfile Registry'
   export const PLUGIN_REGISTRY = 'Plugin Registry'
   export const CHE_OPERATOR = `${PRODUCT_NAME} Operator`
@@ -76,7 +76,6 @@ export namespace EclipseChe {
   export const CHE_SERVER_DEPLOYMENT_NAME = `${CHE_FLAVOR}`
   export const DASHBOARD_DEPLOYMENT_NAME = `${CHE_FLAVOR}-dashboard`
   export const GATEWAY_DEPLOYMENT_NAME = 'che-gateway'
-  export const POSTGRES_DEPLOYMENT_NAME = 'postgres'
   export const DEVFILE_REGISTRY_DEPLOYMENT_NAME = 'devfile-registry'
   export const PLUGIN_REGISTRY_DEPLOYMENT_NAME = 'plugin-registry'
 
@@ -84,7 +83,6 @@ export namespace EclipseChe {
   export const CHE_OPERATOR_SELECTOR = `app.kubernetes.io/name=${CHE_FLAVOR},app.kubernetes.io/component=${CHE_FLAVOR}-operator`
   export const CHE_SERVER_SELECTOR = `app.kubernetes.io/name=${CHE_FLAVOR},app.kubernetes.io/component=${CHE_FLAVOR}`
   export const DASHBOARD_SELECTOR = `app.kubernetes.io/name=${CHE_FLAVOR},app.kubernetes.io/component=${CHE_FLAVOR}-dashboard`
-  export const POSTGRES_SELECTOR = `app.kubernetes.io/name=${CHE_FLAVOR},app.kubernetes.io/component=postgres`
   export const DEVFILE_REGISTRY_SELECTOR = `app.kubernetes.io/name=${CHE_FLAVOR},app.kubernetes.io/component=devfile-registry`
   export const PLUGIN_REGISTRY_SELECTOR = `app.kubernetes.io/name=${CHE_FLAVOR},app.kubernetes.io/component=plugin-registry`
   export const GATEWAY_SELECTOR = `app.kubernetes.io/name=${CHE_FLAVOR},app.kubernetes.io/component=che-gateway`
